# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
import typing



class RegistryError(IntEnum):
    REGISTRY_ALREADY_EXISTS = 0
    REGISTRY_NOT_FOUND = 1
    NOT_AUTHORIZED = 2




class Registry(BaseModel):

    _one_of_dict = {"Registry._name": {"fields": {"name"}}, "Registry._uri": {"fields": {"uri"}}, "Registry._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    user_id: str = FieldInfo(default="") 
    uri: str = FieldInfo(default="") 




class RegistryCredentials(BaseModel):

    _one_of_dict = {"RegistryCredentials._password": {"fields": {"password"}}, "RegistryCredentials._username": {"fields": {"username"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    username: str = FieldInfo(default="") 
    password: str = FieldInfo(default="") 




class RegistryCreationRequest(BaseModel):

    _one_of_dict = {"RegistryCreationRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 




class RegistryCreationResponse(BaseModel):

    _one_of_dict = {"RegistryCreationResponse._registry": {"fields": {"registry"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    registry: Registry = FieldInfo() 




class RegistryCreationResponseError(BaseModel):

    _one_of_dict = {"RegistryCreationResponseError._error": {"fields": {"error"}}, "RegistryCreationResponseError._error_message": {"fields": {"error_message"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: RegistryError = FieldInfo(default=0) 
    error_message: str = FieldInfo(default="") 




class RegistryListRequest(BaseModel):

    _one_of_dict = {"RegistryListRequest._page_number": {"fields": {"page_number"}}, "RegistryListRequest._page_size": {"fields": {"page_size"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    page_size: int = FieldInfo(default=0) 
    page_number: int = FieldInfo(default=0) 




class RegistryListResponse(BaseModel):

    registries: typing.List[Registry] = FieldInfo(default_factory=list) 




class RegistryGetRequest(BaseModel):

    _one_of_dict = {"RegistryGetRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 




class RegistryGetResponse(BaseModel):

    _one_of_dict = {"RegistryGetResponse._registry": {"fields": {"registry"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    registry: Registry = FieldInfo() 




class RegistryGetResponseError(BaseModel):

    _one_of_dict = {"RegistryGetResponseError._error": {"fields": {"error"}}, "RegistryGetResponseError._error_message": {"fields": {"error_message"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: RegistryError = FieldInfo(default=0) 
    error_message: str = FieldInfo(default="") 




class RegistryDeleteRequest(BaseModel):

    _one_of_dict = {"RegistryDeleteRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 




class RegistryDeleteResponseError(BaseModel):

    _one_of_dict = {"RegistryDeleteResponseError._error": {"fields": {"error"}}, "RegistryDeleteResponseError._error_message": {"fields": {"error_message"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: RegistryError = FieldInfo(default=0) 
    error_message: str = FieldInfo(default="") 




class RegistryCredentialsRequest(BaseModel):

    _one_of_dict = {"RegistryCredentialsRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 




class RegistryCredentialsResponse(BaseModel):

    _one_of_dict = {"RegistryCredentialsResponse._credentials": {"fields": {"credentials"}}, "RegistryCredentialsResponse._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    credentials: RegistryCredentials = FieldInfo() 




class RegistryCredentialsResponseError(BaseModel):

    _one_of_dict = {"RegistryCredentialsResponseError._error": {"fields": {"error"}}, "RegistryCredentialsResponseError._error_message": {"fields": {"error_message"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: RegistryError = FieldInfo(default=0) 
    error_message: str = FieldInfo(default="") 





# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
import typing





class TokenData(BaseModel):

    _one_of_dict = {"TokenData._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: str = FieldInfo(default="") 
    scopes: typing.List[str] = FieldInfo(default_factory=list) 




class Profile(BaseModel):

    _one_of_dict = {"Profile._company": {"fields": {"company"}}, "Profile._first_name": {"fields": {"first_name"}}, "Profile._last_name": {"fields": {"last_name"}}, "Profile._phone": {"fields": {"phone"}}, "Profile._product_updates": {"fields": {"product_updates"}}, "Profile._profile_picture_url": {"fields": {"profile_picture_url"}}, "Profile._role": {"fields": {"role"}}, "Profile._targeted_use": {"fields": {"targeted_use"}}, "Profile._timezone": {"fields": {"timezone"}}, "Profile._user_id": {"fields": {"user_id"}}, "Profile._user_presentation": {"fields": {"user_presentation"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: str = FieldInfo(default="") 
    first_name: str = FieldInfo(default="") 
    last_name: str = FieldInfo(default="") 
    company: str = FieldInfo(default="") 
    role: str = FieldInfo(default="") 
    timezone: str = FieldInfo(default="") 
    profile_picture_url: str = FieldInfo(default="") 
    user_presentation: str = FieldInfo(default="") 
    targeted_use: str = FieldInfo(default="") 
    product_updates: bool = FieldInfo(default=False) 
    phone: str = FieldInfo(default="") 





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aimodel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\raimodel.proto\x12\x07\x61imodel\x1a\x0evalidate.proto\"\x97\x02\n\x07\x41IModel\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08provider\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05image\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x14\n\x07\x65nabled\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x11\n\x04type\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x17\n\nrestricted\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nname_alias\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x0b\n\t_providerB\x08\n\x06_imageB\n\n\x08_enabledB\x07\n\x05_typeB\r\n\x0b_restrictedB\r\n\x0b_name_alias\"\x8f\x02\n\x12\x43ompletionResponse\x12\x1f\n\x08model_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x13\n\x0b\x63ompletions\x18\x02 \x03(\t\x12\x19\n\x0cinput_tokens\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\routput_tokens\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1d\n\x10image_resolution\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0bimage_steps\x18\x06 \x01(\x05H\x04\x88\x01\x01\x42\x0b\n\t_model_idB\x0f\n\r_input_tokensB\x10\n\x0e_output_tokensB\x13\n\x11_image_resolutionB\x0e\n\x0c_image_steps\"\xab\x01\n\x14\x41IModelResponseError\x12(\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.aimodel.AIModelErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"d\n\x12\x41IModelListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"\xa0\x01\n\x13\x41IModelListResponse\x12\"\n\x08\x61imodels\x18\x01 \x03(\x0b\x32\x10.aimodel.AIModel\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\x0e\n\x0c_page_numberB\x08\n\x06_error\"5\n\x11\x41IModelGetRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x05\n\x03_id\"\x85\x01\n\x12\x41IModelGetResponse\x12&\n\x07\x61imodel\x18\x01 \x01(\x0b\x32\x10.aimodel.AIModelH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\n\n\x08_aimodelB\x08\n\x06_error\"^\n\x18\x41IModelCompletionRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_payload\"\x9d\x01\n\x19\x41IModelCompletionResponse\x12\x34\n\ncompletion\x18\x01 \x01(\x0b\x32\x1b.aimodel.CompletionResponseH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\r\n\x0b_completionB\x08\n\x06_error\"\x89\x02\n\x1b\x41IModelAdminCreationRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08provider\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05image\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07\x65nabled\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x17\n\nrestricted\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x17\n\nname_alias\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_providerB\x08\n\x06_imageB\n\n\x08_enabledB\x07\n\x05_typeB\r\n\x0b_restrictedB\r\n\x0b_name_alias\"\x8f\x01\n\x1c\x41IModelAdminCreationResponse\x12&\n\x07\x61imodel\x18\x01 \x01(\x0b\x32\x10.aimodel.AIModelH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x01\x88\x01\x01\x42\n\n\x08_aimodelB\x08\n\x06_error\"=\n\x19\x41IModelAdminDeleteRequest\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x05\n\x03_id\"Y\n\x1a\x41IModelAdminDeleteResponse\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.aimodel.AIModelResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\xa4\x01\n\x0c\x41IModelError\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x01\x12\r\n\tNOT_FOUND\x10\x02\x12\x0f\n\x0bNOT_UPDATED\x10\x03\x12\x12\n\x0eNOT_AUTHORIZED\x10\x04\x12\x1a\n\x16\x41IMODEL_OUT_OF_CREDITS\x10\x05\x12\"\n\x1e\x41IMODEL_DONT_HANDLE_COMPLETION\x10\x06\x42\x30Z.github.com/jupyter-naas/naas-models/go/aimodelb\x06proto3')

_AIMODELERROR = DESCRIPTOR.enum_types_by_name['AIModelError']
AIModelError = enum_type_wrapper.EnumTypeWrapper(_AIMODELERROR)
NO_ERROR = 0
ALREADY_EXISTS = 1
NOT_FOUND = 2
NOT_UPDATED = 3
NOT_AUTHORIZED = 4
AIMODEL_OUT_OF_CREDITS = 5
AIMODEL_DONT_HANDLE_COMPLETION = 6


_AIMODEL = DESCRIPTOR.message_types_by_name['AIModel']
_COMPLETIONRESPONSE = DESCRIPTOR.message_types_by_name['CompletionResponse']
_AIMODELRESPONSEERROR = DESCRIPTOR.message_types_by_name['AIModelResponseError']
_AIMODELLISTREQUEST = DESCRIPTOR.message_types_by_name['AIModelListRequest']
_AIMODELLISTRESPONSE = DESCRIPTOR.message_types_by_name['AIModelListResponse']
_AIMODELGETREQUEST = DESCRIPTOR.message_types_by_name['AIModelGetRequest']
_AIMODELGETRESPONSE = DESCRIPTOR.message_types_by_name['AIModelGetResponse']
_AIMODELCOMPLETIONREQUEST = DESCRIPTOR.message_types_by_name['AIModelCompletionRequest']
_AIMODELCOMPLETIONRESPONSE = DESCRIPTOR.message_types_by_name['AIModelCompletionResponse']
_AIMODELADMINCREATIONREQUEST = DESCRIPTOR.message_types_by_name['AIModelAdminCreationRequest']
_AIMODELADMINCREATIONRESPONSE = DESCRIPTOR.message_types_by_name['AIModelAdminCreationResponse']
_AIMODELADMINDELETEREQUEST = DESCRIPTOR.message_types_by_name['AIModelAdminDeleteRequest']
_AIMODELADMINDELETERESPONSE = DESCRIPTOR.message_types_by_name['AIModelAdminDeleteResponse']
AIModel = _reflection.GeneratedProtocolMessageType('AIModel', (_message.Message,), {
  'DESCRIPTOR' : _AIMODEL,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModel)
  })
_sym_db.RegisterMessage(AIModel)

CompletionResponse = _reflection.GeneratedProtocolMessageType('CompletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETIONRESPONSE,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.CompletionResponse)
  })
_sym_db.RegisterMessage(CompletionResponse)

AIModelResponseError = _reflection.GeneratedProtocolMessageType('AIModelResponseError', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELRESPONSEERROR,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelResponseError)
  })
_sym_db.RegisterMessage(AIModelResponseError)

AIModelListRequest = _reflection.GeneratedProtocolMessageType('AIModelListRequest', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELLISTREQUEST,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelListRequest)
  })
_sym_db.RegisterMessage(AIModelListRequest)

AIModelListResponse = _reflection.GeneratedProtocolMessageType('AIModelListResponse', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELLISTRESPONSE,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelListResponse)
  })
_sym_db.RegisterMessage(AIModelListResponse)

AIModelGetRequest = _reflection.GeneratedProtocolMessageType('AIModelGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELGETREQUEST,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelGetRequest)
  })
_sym_db.RegisterMessage(AIModelGetRequest)

AIModelGetResponse = _reflection.GeneratedProtocolMessageType('AIModelGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELGETRESPONSE,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelGetResponse)
  })
_sym_db.RegisterMessage(AIModelGetResponse)

AIModelCompletionRequest = _reflection.GeneratedProtocolMessageType('AIModelCompletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELCOMPLETIONREQUEST,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelCompletionRequest)
  })
_sym_db.RegisterMessage(AIModelCompletionRequest)

AIModelCompletionResponse = _reflection.GeneratedProtocolMessageType('AIModelCompletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELCOMPLETIONRESPONSE,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelCompletionResponse)
  })
_sym_db.RegisterMessage(AIModelCompletionResponse)

AIModelAdminCreationRequest = _reflection.GeneratedProtocolMessageType('AIModelAdminCreationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELADMINCREATIONREQUEST,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelAdminCreationRequest)
  })
_sym_db.RegisterMessage(AIModelAdminCreationRequest)

AIModelAdminCreationResponse = _reflection.GeneratedProtocolMessageType('AIModelAdminCreationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELADMINCREATIONRESPONSE,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelAdminCreationResponse)
  })
_sym_db.RegisterMessage(AIModelAdminCreationResponse)

AIModelAdminDeleteRequest = _reflection.GeneratedProtocolMessageType('AIModelAdminDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELADMINDELETEREQUEST,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelAdminDeleteRequest)
  })
_sym_db.RegisterMessage(AIModelAdminDeleteRequest)

AIModelAdminDeleteResponse = _reflection.GeneratedProtocolMessageType('AIModelAdminDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _AIMODELADMINDELETERESPONSE,
  '__module__' : 'aimodel_pb2'
  # @@protoc_insertion_point(class_scope:aimodel.AIModelAdminDeleteResponse)
  })
_sym_db.RegisterMessage(AIModelAdminDeleteResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/aimodel'
  _AIMODEL.fields_by_name['id']._options = None
  _AIMODEL.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _COMPLETIONRESPONSE.fields_by_name['model_id']._options = None
  _COMPLETIONRESPONSE.fields_by_name['model_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _AIMODELGETREQUEST.fields_by_name['id']._options = None
  _AIMODELGETREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _AIMODELCOMPLETIONREQUEST.fields_by_name['id']._options = None
  _AIMODELCOMPLETIONREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _AIMODELADMINDELETEREQUEST.fields_by_name['id']._options = None
  _AIMODELADMINDELETEREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _AIMODELERROR._serialized_start=2053
  _AIMODELERROR._serialized_end=2217
  _AIMODEL._serialized_start=43
  _AIMODEL._serialized_end=322
  _COMPLETIONRESPONSE._serialized_start=325
  _COMPLETIONRESPONSE._serialized_end=596
  _AIMODELRESPONSEERROR._serialized_start=599
  _AIMODELRESPONSEERROR._serialized_end=770
  _AIMODELLISTREQUEST._serialized_start=772
  _AIMODELLISTREQUEST._serialized_end=872
  _AIMODELLISTRESPONSE._serialized_start=875
  _AIMODELLISTRESPONSE._serialized_end=1035
  _AIMODELGETREQUEST._serialized_start=1037
  _AIMODELGETREQUEST._serialized_end=1090
  _AIMODELGETRESPONSE._serialized_start=1093
  _AIMODELGETRESPONSE._serialized_end=1226
  _AIMODELCOMPLETIONREQUEST._serialized_start=1228
  _AIMODELCOMPLETIONREQUEST._serialized_end=1322
  _AIMODELCOMPLETIONRESPONSE._serialized_start=1325
  _AIMODELCOMPLETIONRESPONSE._serialized_end=1482
  _AIMODELADMINCREATIONREQUEST._serialized_start=1485
  _AIMODELADMINCREATIONREQUEST._serialized_end=1750
  _AIMODELADMINCREATIONRESPONSE._serialized_start=1753
  _AIMODELADMINCREATIONRESPONSE._serialized_end=1896
  _AIMODELADMINDELETEREQUEST._serialized_start=1898
  _AIMODELADMINDELETEREQUEST._serialized_end=1959
  _AIMODELADMINDELETERESPONSE._serialized_start=1961
  _AIMODELADMINDELETERESPONSE._serialized_end=2050
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: iam.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tiam.proto\x12\x03iam\x1a\x0evalidate.proto\"=\n\tTokenData\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06scopes\x18\x02 \x03(\tB\n\n\x08_user_id\"\xc7\x03\n\x07Profile\x12\x14\n\x07user_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nfirst_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tlast_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07\x63ompany\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04role\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08timezone\x18\x06 \x01(\tH\x05\x88\x01\x01\x12 \n\x13profile_picture_url\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1e\n\x11user_presentation\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x19\n\x0ctargeted_use\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1c\n\x0fproduct_updates\x18\n \x01(\x08H\t\x88\x01\x01\x12\x12\n\x05phone\x18\x0b \x01(\tH\n\x88\x01\x01\x42\n\n\x08_user_idB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\n\n\x08_companyB\x07\n\x05_roleB\x0b\n\t_timezoneB\x16\n\x14_profile_picture_urlB\x14\n\x12_user_presentationB\x0f\n\r_targeted_useB\x12\n\x10_product_updatesB\x08\n\x06_phoneB,Z*github.com/jupyter-naas/naas-models/go/iamb\x06proto3')



_TOKENDATA = DESCRIPTOR.message_types_by_name['TokenData']
_PROFILE = DESCRIPTOR.message_types_by_name['Profile']
TokenData = _reflection.GeneratedProtocolMessageType('TokenData', (_message.Message,), {
  'DESCRIPTOR' : _TOKENDATA,
  '__module__' : 'iam_pb2'
  # @@protoc_insertion_point(class_scope:iam.TokenData)
  })
_sym_db.RegisterMessage(TokenData)

Profile = _reflection.GeneratedProtocolMessageType('Profile', (_message.Message,), {
  'DESCRIPTOR' : _PROFILE,
  '__module__' : 'iam_pb2'
  # @@protoc_insertion_point(class_scope:iam.Profile)
  })
_sym_db.RegisterMessage(Profile)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/jupyter-naas/naas-models/go/iam'
  _TOKENDATA._serialized_start=34
  _TOKENDATA._serialized_end=95
  _PROFILE._serialized_start=98
  _PROFILE._serialized_end=553
# @@protoc_insertion_point(module_scope)
